pub struct ChangeDelta<T> { /* private fields */ }Expand description
Describes a change-delta representing replaced content between original and revised sequences.
Implementations
Sourceimpl<T> ChangeDelta<T>
impl<T> ChangeDelta<T>
Sourcepub fn new(source: Chunk<T>, target: Chunk<T>) -> Self
pub fn new(source: Chunk<T>, target: Chunk<T>) -> Self
Creates a new ChangeDelta with the given source and target chunks.
Sourcepub fn into_delta(self) -> Delta<T>
pub fn into_delta(self) -> Delta<T>
Consumes self and returns the inner Delta.
Sourcepub fn apply_to(&self, target: &mut Vec<T>) -> Result<(), PatchError>
pub fn apply_to(&self, target: &mut Vec<T>) -> Result<(), PatchError>
Applies this change delta to the target vector.
Replaces the element range at the source chunk’s position with the target chunk’s lines.
Sourcepub fn restore(&self, target: &mut Vec<T>) -> Result<(), PatchError>
pub fn restore(&self, target: &mut Vec<T>) -> Result<(), PatchError>
Restores (un-applies) this change delta on the target sequence.
Replaces the element range at the target chunk’s position with the original source lines.
Sourcepub fn apply_fuzzy_to_at(
&self,
target: &mut Vec<T>,
_fuzz: usize,
position: usize,
) -> Result<(), PatchError>
pub fn apply_fuzzy_to_at( &self, target: &mut Vec<T>, _fuzz: usize, position: usize, ) -> Result<(), PatchError>
Applies the patch with a fuzzy tolerance context offset.
Sourcepub fn with_chunks(&self, original: Chunk<T>, revised: Chunk<T>) -> Self
pub fn with_chunks(&self, original: Chunk<T>, revised: Chunk<T>) -> Self
Creates a new ChangeDelta with custom source and target chunks.