pub struct InsertDelta<T> { /* private fields */ }Expand description
Describes an insert-delta representing new content added to a target sequence.
Implementations
Sourceimpl<T> InsertDelta<T>
impl<T> InsertDelta<T>
Sourcepub fn new(original: Chunk<T>, revised: Chunk<T>) -> Self
pub fn new(original: Chunk<T>, revised: Chunk<T>) -> Self
Creates a new InsertDelta with the given original (source) and revised (target) chunks.
Sourcepub fn into_delta(self) -> Delta<T>
pub fn into_delta(self) -> Delta<T>
Consumes self and returns the inner Delta.
Sourcepub fn apply_to(&self, target: &mut Vec<T>) -> Result<(), PatchError>where
T: Clone,
pub fn apply_to(&self, target: &mut Vec<T>) -> Result<(), PatchError>where
T: Clone,
Applies this insert delta to the target vector.
Inserts the revised chunk lines at the source chunk’s target position.
Sourcepub fn restore(&self, target: &mut Vec<T>) -> Result<(), PatchError>
pub fn restore(&self, target: &mut Vec<T>) -> Result<(), PatchError>
Restores (un-applies) this insert delta on the target vector.
Removes/drains the inserted target lines from the target vector.
Sourcepub fn with_chunks(&self, original: Chunk<T>, revised: Chunk<T>) -> Self
pub fn with_chunks(&self, original: Chunk<T>, revised: Chunk<T>) -> Self
Creates a new InsertDelta with custom source and target chunks.