Holds the information required to merge deltas originating from an inline diff.
Structs
- Inline
Delta Merge Info - Holds the information required to merge deltas originating from an inline diff.
Holds the information required to merge deltas originating from an inline diff.