Generates DiffRow instances for side-by-side or inline text views.
Structs
- Builder
- Builder for constructing customized
DiffRowGeneratorinstances. - Diff
RowGenerator - Primary generator for
DiffRowside-by-side views. - SPLIT_
BY_ WORD_ PATTERN - WHITESPACE_
EQUALITIES_ MERGER
Functions
- adjust_
whitespace - Adjusts whitespace in a string by collapsing consecutive whitespaces into a single space.
- default_
equalizer - Default equalizer checking strict string equality.
- default_
inline_ delta_ merger - Default inline delta merger returning unmodified deltas.
- html_
line_ normalizer - Default line normalizer for HTML escaping.
- ignore_
whitespace_ equalizer - Equalizer ignoring whitespace differences.
- split_
string_ preserve_ delimiter - Helper function to split a string while preserving matched delimiters.
- splitter_
by_ character - Character-by-character splitter.
- splitter_
by_ word - Word-by-word splitter.
- whitespace_
equalities_ merger - Whitespace equalities inline delta merger.
- wrap_
in_ tag - Wraps elements in a string sequence with start/end tags.