Data structure representing one patched file in a unified diff document.
Structs
- Unified
Diff File - Holds metadata and the patch for a single file in a unified diff.
Data structure representing one patched file in a unified diff document.